pub struct ContextAttributes {
pub numeric: Arc<HashMap<Str, NumericAttribute>>,
pub categorical: Arc<HashMap<Str, CategoricalAttribute>>,
}Expand description
ContextAttributes are subject or action attributes split by their semantics.
Fields
numeric: Arc<HashMap<Str, NumericAttribute>>Numeric attributes are quantitative (e.g., real numbers) and define a scale.
Not all numbers are numeric attributes. If a number is used to represent an enumeration or on/off values, it is a categorical attribute.
categorical: Arc<HashMap<Str, CategoricalAttribute>>Categorical attributes are attributes that have a finite set of values that are not directly comparable (i.e., enumeration).
Implementations
Sourceimpl ContextAttributes
impl ContextAttributes
Sourcepub fn to_generic_attributes(&self) -> Attributes
pub fn to_generic_attributes(&self) -> Attributes
Convert contextual attributes to generic Attributes.