pub struct AssignmentEvent {
pub base: Arc<AssignmentEventBase>,
pub subject: Str,
pub subject_attributes: Arc<Attributes>,
pub timestamp: DateTime<Utc>,
pub evaluation_details: Option<Arc<EvaluationDetails>>,
}Expand description
Represents an event capturing the assignment of a feature flag to a subject and its logging details.
Fields
base: Arc<AssignmentEventBase>subject: StrThe key identifying the subject receiving the assignment.
subject_attributes: Arc<Attributes>Custom attributes of the subject relevant to the assignment.
timestamp: DateTime<Utc>The timestamp indicating when the assignment event occurred.
evaluation_details: Option<Arc<EvaluationDetails>>Evaluation details that could help with debugging the assigment. Only populated when
details-version of the get_assigment was called.